package com.muyu.common.domain.req;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.muyu.common.core.validation.custom.IsSysRuleActivate;
import com.muyu.common.core.validation.custom.IsSysRuleRegion;
import com.muyu.common.core.validation.custom.IsSysRuleZM;
import com.muyu.common.core.validation.custom.IsSystemYesNo;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Author：蓬叁
 * @Package：com.muyu.common.domain.req
 * @Project：cloud-rule
 * @name：RuleDataUpdReq
 * @Date：2024/8/23 上午1:09
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Tag(name = "规则修改请求对象")
public class RuleDataUpdReq {

    /**
     * 规则分类
     */
    @Schema(title = "规则分类", type = "Integer",description = "选择规则分类" )
    private Integer ruleClassify;
    /**
     * 规则名称
     */
    @NotEmpty(message = "规则名称不可为空 ")
    @Schema(title = "规则名称" , type = "String",defaultValue = "XX规则"
            ,description = "规则名称一般为类型名称,方便使用者进行区分" ,requiredProperties = {"ruleName"})
    private String ruleName;
    /**
     * 规则类型
     */
    @NotEmpty(message = "规则类型不可为空")
    @IsSysRuleZM //判断 Z 自定义规则 M 模板规则
    @Schema(description = "规则类型",defaultValue = "Z",type = "String")
    private String ruleType;
    /**
     * 规则作用域
     */
    @NotEmpty(message = "规则作用域不可为空")
    @IsSysRuleRegion
    @Schema(description = "规则作用域",defaultValue = "F",type = "String")
    private String ruleRegion;
    /**
     * 引擎编码
     */
    @NotEmpty(message = "编码不可为空")
    @Schema(description = "引擎编码",defaultValue = "notNull",type = "String")
    private String ruleCoding;
    /**
     * 激活状态
     */
    @NotEmpty(message = "激活状态不可为空")
    @IsSysRuleActivate
    @Schema(description = "激活状态",defaultValue = "S",type = "String")
    private String ruleActivate;
    /**
     * 规则状态
     */
    @NotEmpty(message = "规则状态不可为空 ")
    @IsSystemYesNo
    @Schema(title = "接口开通状态" , type = "String" , defaultValue = "Y",
            description = "状态为Y和N,如果为Y则客户可以使用接口规则，若为N则客户不可以使用接口规则")
    private String ruleStatus;
    /**
     * 规则描述
     */
    @Schema(description = "规则描述",type = "String")
    private String ruleDescribe;

}
