package com.muyu.common.domain.req;

import com.muyu.common.core.validation.custom.IsSysRuleActivate;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import lombok.*;

/**
 * @Author：蓬叁
 * @Package：com.muyu.common.domain.req
 * @Project：cloud-rule
 * @name：RuleVersionAddReq
 * @Date：2024/8/27 下午3:17
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Tag(name = "规则版本添加请求对象")
public class RuleVersionAddReq {

    /**
     * 规则ID
     */
    @NotNull(message = "规则ID不可为空")
    @Schema(title = "规则ID",type = "Long",description = "一对多")
    private Long ruleId ;
    /**
     * 版本类
     */
    @NotEmpty(message = "版本类不可为空")
    @Schema(title = "版本类",type = "String",description = "规则状态+引擎编码+类名")
    private String ruleVersionType ;
    /**
     * 版本名称
     */
    @NotEmpty(message = "版本名称不可为空")
    @Schema(title = "版本名称",type = "String",description = "QQ检验")
    private String ruleVersionName ;
    /**
     * 版本编码
     */
    @NotEmpty(message = "版本编码不可为空")
    @Schema(title = "版本编码",type = "String",description = "email")
    private String ruleVersionCode ;
    /**
     * 是否激活
     */
    @Schema(title = "激活状态",type = "String",description = "U")
    @IsSysRuleActivate
    private String ruleVersionActivate ;
    /**
     * 版本状态
     */
    @Schema(title = "版本状态",type = "String",description = "I")
    private String ruleVersionStatus ;
    /**
     * 代码
     */
    @Schema(title = "代码",type = "String")
    private String ruleVersionText ;
    /**
     * 版本备注
     */
    @Schema(title = "版本备注",type = "String")
    private String remark;
}
