package com.muyu.common.domain.resp;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.validation.custom.IsSysRuleActivate;
import com.muyu.common.domain.RuleData;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * @Author：蓬叁
 * @Package：com.muyu.common.domain.resp
 * @Project：cloud-rule
 * @name：RuleDataResp
 * @Date：2024/8/22 下午9:54
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Tag(name = "接口规则信息对应对象",description = "负责接口规则信息查询的相应结果")
public class RuleDataResp {

    /**
     * 规则ID
     */
    @Schema(description = "规则ID",defaultValue = "1",type = "Long")
    private Long id;
    /**
     * 规则名称
     */
    @Schema(description = "规则名称",defaultValue = "邮箱规则接口",type = "String")
    private String ruleName;
    /**
     * 规则类型
     */
    @Schema(description = "规则类型",defaultValue = "邮箱校验",type = "String")
    private String ruleType;
    /**
     * 规则作用域
     */
    @Schema(description = "规则作用域",defaultValue = "数据字段",type = "String")
    private String ruleRegion;
    /**
     * 引擎编码
     */
    @Schema(description = "引擎编码",defaultValue = "notNull",type = "String")
    private String ruleCoding;
    /**
     * 激活状态
     */
    @Schema(description = "激活状态",defaultValue = "S",type = "String")
    private String ruleActivate;
    /**
     * 规则状态
     */
    @Schema(description = "规则状态",defaultValue = "Y",type = "String")
    private String ruleStatus;
    /**
     * 规则描述
     */
    @Schema(description = "规则描述",type = "String")
    private String ruleDescribe;
    /**
     * 创建时间
     */
    @Schema(description = "创建时间",type = "Date")
    private Date createTime;

    public static RuleDataResp ruleDataBuild(RuleData ruleData, Supplier<List<RuleDataResp>> function) {
        return RuleDataResp.builder()
                .id(ruleData.getRuleId())
                .ruleName(ruleData.getRuleName())
                .ruleType(ruleData.getRuleType())
                .ruleRegion(ruleData.getRuleRegion())
                .ruleCoding(ruleData.getRuleCoding())
                .ruleActivate(ruleData.getRuleActivate())
                .ruleStatus(ruleData.getRuleStatus())
                .build();
    }
}
