package com.muyu.servier.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.enums.SysRuleActivate;
import com.muyu.common.core.enums.SystemYesNo;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.domain.RuleData;
import com.muyu.common.domain.req.RuleDataListReq;
import com.muyu.common.domain.resp.RuleDataResp;
import com.muyu.mapper.RuleDataMapper;
import com.muyu.servier.RuleDataInfoService;
import com.muyu.servier.RuleDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：蓬叁
 * @Package：com.muyu.servier.impl
 * @Project：cloud-rule
 * @name：RuleDataServiceImpl
 * @Date：2024/8/22 下午10:21
 */
@Service
public class RuleDataServiceImpl
        extends ServiceImpl<RuleDataMapper, RuleData>
        implements RuleDataService {

    @Autowired private RuleDataInfoService ruleDataInfoService;

    @Override
    public List<RuleDataResp> selectList(RuleDataListReq ruleDataListReq) {
        LambdaQueryWrapper<RuleData> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(
                StringUtils.isNotEmpty(ruleDataListReq.getRuleName()),
                RuleData::getRuleName, ruleDataListReq.getRuleName()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(ruleDataListReq.getRuleType()),
                RuleData::getRuleType, ruleDataListReq.getRuleType()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(ruleDataListReq.getRuleActivate()),
                RuleData::getRuleActivate, ruleDataListReq.getRuleActivate()
        );
        queryWrapper.eq(
                StringUtils.isNotEmpty(ruleDataListReq.getRuleStatus()),
                RuleData::getRuleStatus, ruleDataListReq.getRuleStatus()
        );
        List<RuleData> ruleDataList = this.list(queryWrapper);
        return ruleDataList.stream()
                .map(ruleData -> RuleDataResp.ruleDataBuild(ruleData,() ->
                        ruleDataInfoService.selectRuleDataAndLimit(ruleData.getRuleId(),5)
                                .stream()
                                .toList()
                                ))
                .toList();
    }

    @Override
    public void disable(Long ruleId) {
        this.settingStatus(ruleId, SystemYesNo.NO.getCode());
    }

    @Override
    public void enable(Long ruleId) {
        this.settingStatus(ruleId, SystemYesNo.YES.getCode());
    }

    @Override
    public void settingStatus(Long ruleId, String status) {
        LambdaQueryWrapper<RuleData> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RuleData::getRuleId,ruleId);
        boolean isExists = this.exists(queryWrapper);
        if (!isExists) {
            throw new ServiceException("操作规则不存在");
        }
        if (!SystemYesNo.isCode(status)){
            throw new ServiceException("设置状态值违法");
        }
        LambdaUpdateWrapper<RuleData> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(RuleData::getRuleId,ruleId);
        updateWrapper.set(RuleData::getRuleStatus,status);
        this.update(updateWrapper);
    }

    @Override
    public void unstart(Long ruleId) {
        this.settingActivate(ruleId, SysRuleActivate.UNSTART.getCode());
    }

    @Override
    public void start(Long ruleId) {
        this.settingActivate(ruleId, SysRuleActivate.START.getCode());
    }

    @Override
    public void settingActivate(Long ruleId, String activate) {
        LambdaQueryWrapper<RuleData> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RuleData::getRuleId,ruleId);
        boolean isExists = this.exists(queryWrapper);
        if (!isExists) {
            throw new ServiceException("操作规则不存在");
        }
        if (!SysRuleActivate.isCode(activate)){
            throw new ServiceException("设置状态值违法");
        }
        LambdaUpdateWrapper<RuleData> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(RuleData::getRuleId,ruleId);
        updateWrapper.set(RuleData::getRuleActivate,activate);
        this.update(updateWrapper);
    }

}
