package com.muyu.servier.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.enums.SysRuleActivate;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.common.domain.RuleData;
import com.muyu.common.domain.RuleVersion;
import com.muyu.common.domain.req.RuleVersionUpdReq;
import com.muyu.common.domain.resp.RuleVersionResp;
import com.muyu.constant.GenerateConstant;
import com.muyu.load.OSSFileLoad;
import com.muyu.mapper.RuleVersionMapper;
import com.muyu.servier.RuleDataService;
import com.muyu.servier.RuleVersionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Author：蓬叁
 * @Package：com.muyu.servier.impl
 * @Project：cloud-rule
 * @name：RuleVersionServiceImpl
 * @Date：2024/8/27 上午11:47
 */
@Service
public class RuleVersionServiceImpl
        extends ServiceImpl<RuleVersionMapper, RuleVersion>
        implements RuleVersionService {

    @Autowired private RuleVersionMapper ruleVersionMapper;
    @Autowired private RuleDataService ruleDataService;

    @Override
    public List<RuleVersionResp> selectList(Long ruleId) {
        List<RuleVersionResp> ruleVersion = ruleVersionMapper.selectByIdList(ruleId);
        return ruleVersion;
    }

    @Override
    public void updateStatus(Long ruleVersionId, RuleVersionUpdReq ruleVersionUpdReq) {
        ruleVersionMapper.updateStatus(ruleVersionId,ruleVersionUpdReq);
    }

    @Override
    public void unstart(Long ruleVersionId) {
        this.settingVersionActivate(ruleVersionId, SysRuleActivate.UNSTART.getCode());
    }

    @Override
    public void start(Long ruleVersionId) {
        this.settingVersionActivate(ruleVersionId, SysRuleActivate.START.getCode());
    }

    @Override
    public void settingVersionActivate(Long ruleVersionId, String activate) {
        LambdaQueryWrapper<RuleVersion> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RuleVersion::getRuleVersionId,ruleVersionId);
        boolean isExists = this.exists(queryWrapper);
        if (!isExists) {
            throw new ServiceException("操作规则不存在");
        }
        if (!SysRuleActivate.isCode(activate)){
            throw new ServiceException("设置状态值违法");
        }
        LambdaUpdateWrapper<RuleVersion> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(RuleVersion::getRuleVersionId,ruleVersionId);
        updateWrapper.set(RuleVersion::getRuleVersionActivate,activate);
        this.update(updateWrapper);
    }

    @Override
    public RuleVersion generatedCode(RuleVersion ruleVersion) {
        RuleData ruleData = ruleDataService.getById(ruleVersion.getRuleId());
        ruleVersion.setRuleVersionType(getClassName("generate"+"_"+ruleData.getRuleCoding()+"_"+ruleVersion.getRuleVersionCode()));
        ruleVersion.setRuleVersionText(GenerateConstant.generateConstant(ruleData,ruleVersion));
        return ruleVersion;
    }

    public static String getClassName(String versionCode){
        String[] splits = versionCode.split("_");
        String className="";
        for (String split : splits) {
            className += split.substring(0,1).toUpperCase()+split.substring(1);
        }
        return className;
    }

}
