package com.muyu.util;

import cn.hutool.core.util.DesensitizedUtil;
import cn.hutool.core.util.StrUtil;

public class DesensitizationUtil {

    /**
     * 对字符串进行脱敏处理，保留最后几位，其余替换为星号。
     *
     * @param data   原始字符串
     * @param keep   保留的字符数，从字符串末尾开始计数
     * @param symbol 脱敏使用的字符，默认为星号 '*'
     * @return 脱敏后的字符串
     */
    public static String desensitize(String data, int keep, char symbol) {
        if (data == null || data.isEmpty() || keep >= data.length()) {
            return data;
        }
        StringBuilder sb = new StringBuilder(data);
        for (int i = 0; i < data.length() - keep; i++) {
            sb.setCharAt(i, symbol);
        }
        return sb.toString();
    }

    /**
     * 手机号码 前三位，后4位，其他隐藏
     *
     * @param num 移动电话；
     * @return 脱敏后的移动电话；
     */
    public static String mobilePhone(String num) {
        if (StrUtil.isBlank(num)) {
            return StrUtil.EMPTY;
        }
        return StrUtil.hide(num, 3, num.length() - 4);
    }

    /**
     * 对邮箱地址进行脱敏处理，通常保留最后两位。
     *
     * @param email 邮箱地址
     * @return 脱敏后的邮箱地址
     */
    public static String desensitizeEmail(String email) {
        int atIndex = email.lastIndexOf('@');
        if (atIndex == -1) {
            return email;
        }
        String localPart = email.substring(0, atIndex - 2); // 邮箱本地部分减去最后两位
        return desensitize(localPart, 2, '*') + email.substring(atIndex - 2);
    }

    /**
     * 身份证号 前1位 和后2位
     *
     * @param idCardNum 身份证
     * @param front     保留：前面的front位数；从1开始
     * @param end       保留：后面的end位数；从1开始
     * @return 脱敏后的身份证
     */
    public static String idCardNum(String idCardNum, int front, int end) {
        if (StrUtil.isBlank(idCardNum)) {
            return StrUtil.EMPTY;
        }
        if ((front + end) > idCardNum.length()) {
            return StrUtil.EMPTY;
        }
        if (front < 0 || end < 0) {
            return StrUtil.EMPTY;
        }
        return StrUtil.hide(idCardNum, front, idCardNum.length() - end);
    }



}
